about summary refs log tree commit homepage
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/mongrel/init.rb10
-rw-r--r--lib/mongrel/mime_types.yml616
-rw-r--r--lib/unicorn.rb (renamed from lib/mongrel.rb)25
-rw-r--r--lib/unicorn/const.rb (renamed from lib/mongrel/const.rb)16
-rw-r--r--lib/unicorn/header_out.rb (renamed from lib/mongrel/header_out.rb)2
-rw-r--r--lib/unicorn/http_request.rb (renamed from lib/mongrel/http_request.rb)6
-rw-r--r--lib/unicorn/http_response.rb (renamed from lib/mongrel/http_response.rb)4
-rw-r--r--lib/unicorn/semaphore.rb (renamed from lib/mongrel/semaphore.rb)0
-rw-r--r--lib/unicorn/tcphack.rb (renamed from lib/mongrel/tcphack.rb)0
9 files changed, 26 insertions, 653 deletions
diff --git a/lib/mongrel/init.rb b/lib/mongrel/init.rb
deleted file mode 100644
index 00911f4..0000000
--- a/lib/mongrel/init.rb
+++ /dev/null
@@ -1,10 +0,0 @@
-# Copyright (c) 2005 Zed A. Shaw
-# You can redistribute it and/or modify it under the same terms as Ruby.
-#
-# Additional work donated by contributors.  See http://mongrel.rubyforge.org/attributions.html
-# for more information.
-
-require 'mongrel/gems'
-Mongrel::Gems.require 'gem_plugin'
-
-# File is just a stub that makes sure the mongrel_plugins gem is loaded and ready
diff --git a/lib/mongrel/mime_types.yml b/lib/mongrel/mime_types.yml
deleted file mode 100644
index 3ce1739..0000000
--- a/lib/mongrel/mime_types.yml
+++ /dev/null
@@ -1,616 +0,0 @@
----
-.a: application/octet-stream
-.abc: text/vnd.abc
-.acgi: text/html
-.afl: video/animaflex
-.ai: application/postscript
-.aif: audio/aiff
-.aifc: audio/aiff
-.aiff: audio/aiff
-.aip: text/x-audiosoft-intra
-.ani: application/x-navi-animation
-.aps: application/mime
-.arc: application/octet-stream
-.arj: application/octet-stream
-.art: image/x-jg
-.asf: video/x-ms-asf
-.asm: text/x-asm
-.asp: text/asp
-.asr: video/x-ms-asf
-.asx: video/x-ms-asf
-.atom: application/atom+xml
-.au: audio/basic
-.au: audio/x-au
-.avi: video/avi
-.avs: video/avs-video
-.axs: application/olescript
-.bas: text/plain
-.bcpio: application/x-bcpio
-.bin: application/octet-stream
-.bm: image/bmp
-.bmp: image/bmp
-.boo: application/book
-.book: application/book
-.boz: application/x-bzip2
-.bsh: application/x-bsh
-.bz2: application/x-bzip2
-.bz: application/x-bzip
-.c: text/plain
-.cat: application/octet-stream
-.cc: text/plain
-.ccad: application/clariscad
-.cco: application/x-cocoa
-.cdf: application/cdf
-.cer: application/x-x509-ca-cert
-.cha: application/x-chat
-.chat: application/x-chat
-.class: application/java
-.class: application/octet-stream
-.clp: application/x-msclip
-.cmx: image/x-cmx
-.cod: image/cis-cod
-.com: application/octet-stream
-.com: text/plain
-.conf: text/plain
-.cpio: application/x-cpio
-.cpp: text/x-c
-.cpt: application/x-cpt
-.crd: application/x-mscardfile
-.crl: application/pkcs-crl
-.crl: application/pkix-crl
-.crt: application/x-x509-ca-cert
-.csh: application/x-csh
-.csh: text/x-script.csh
-.css: text/css
-.cxx: text/plain
-.dcr: application/x-director
-.deb: application/octet-stream
-.deepv: application/x-deepv
-.def: text/plain
-.der: application/x-x509-ca-cert
-.dhh: application/david-heinemeier-hansson
-.dif: video/x-dv
-.dir: application/x-director
-.dl: video/dl
-.dll: application/octet-stream
-.dmg: application/octet-stream
-.dms: application/octet-stream
-.doc: application/msword
-.dp: application/commonground
-.drw: application/drafting
-.dump: application/octet-stream
-.dv: video/x-dv
-.dvi: application/x-dvi
-.dwg: application/acad
-.dwg: image/x-dwg
-.dxf: application/dxf
-.dxf: image/x-dwg
-.dxr: application/x-director
-.ear: application/java-archive
-.el: text/x-script.elisp
-.elc: application/x-bytecode.elisp (compiled elisp)
-.elc: application/x-elc
-.env: application/x-envoy
-.eot: application/octet-stream
-.eps: application/postscript
-.es: application/x-esrehber
-.etx: text/x-setext
-.evy: application/envoy
-.evy: application/x-envoy
-.exe: application/octet-stream
-.f77: text/x-fortran
-.f90: text/plain
-.f90: text/x-fortran
-.f: text/x-fortran
-.fdf: application/vnd.fdf
-.fif: application/fractals
-.fif: image/fif
-.fli: video/fli
-.fli: video/x-fli
-.flo: image/florian
-.flr: x-world/x-vrml
-.flv: video/x-flv
-.flx: text/vnd.fmi.flexstor
-.fmf: video/x-atomic3d-feature
-.for: text/plain
-.for: text/x-fortran
-.fpx: image/vnd.fpx
-.fpx: image/vnd.net-fpx
-.frl: application/freeloader
-.funk: audio/make
-.g3: image/g3fax
-.g: text/plain
-.gif: image/gif
-.gl: video/gl
-.gl: video/x-gl
-.gsd: audio/x-gsm
-.gsm: audio/x-gsm
-.gsp: application/x-gsp
-.gss: application/x-gss
-.gtar: application/x-gtar
-.gz: application/x-compressed
-.gzip: application/x-gzip
-.h: text/plain
-.hdf: application/x-hdf
-.help: application/x-helpfile
-.hgl: application/vnd.hp-hpgl
-.hh: text/plain
-.hlb: text/x-script
-.hlp: application/hlp
-.hpg: application/vnd.hp-hpgl
-.hpgl: application/vnd.hp-hpgl
-.hqx: application/binhex
-.hta: application/hta
-.htc: text/x-component
-.htm: text/html
-.html: text/html
-.htmls: text/html
-.htt: text/webviewhtml
-.htx: text/html
-.ico: image/x-icon
-.idc: text/plain
-.ief: image/ief
-.iefs: image/ief
-.iges: application/iges
-.igs: application/iges
-.iii: application/x-iphone
-.ima: application/x-ima
-.imap: application/x-httpd-imap
-.img: application/octet-stream
-.inf: application/inf
-.ins: application/x-internet-signup
-.ins: application/x-internett-signup
-.ip: application/x-ip2
-.iso: application/octet-stream
-.isp: application/x-internet-signup
-.isu: video/x-isvideo
-.it: audio/it
-.iv: application/x-inventor
-.ivr: i-world/i-vrml
-.ivy: application/x-livescreen
-.jam: audio/x-jam
-.jar: application/java-archive
-.jardiff: application/x-java-archive-diff
-.jav: text/plain
-.jav: text/x-java-source
-.java: text/plain
-.java: text/x-java-source
-.jcm: application/x-java-commerce
-.jfif-tbnl: image/jpeg
-.jfif: image/jpeg
-.jfif: image/pipeg
-.jfif: image/pjpeg
-.jng: image/x-jng
-.jnlp: application/x-java-jnlp-file
-.jpe: image/jpeg
-.jpeg: image/jpeg
-.jpg: image/jpeg
-.jps: image/x-jps
-.js: application/x-javascript
-.js: text/javascript
-.jut: image/jutvision
-.kar: audio/midi
-.kar: music/x-karaoke
-.ksh: application/x-ksh
-.ksh: text/x-script.ksh
-.la: audio/nspaudio
-.la: audio/x-nspaudio
-.lam: audio/x-liveaudio
-.latex: application/x-latex
-.lha: application/lha
-.lha: application/octet-stream
-.lha: application/x-lha
-.lhx: application/octet-stream
-.list: text/plain
-.lma: audio/nspaudio
-.lma: audio/x-nspaudio
-.log: text/plain
-.lsf: video/x-la-asf
-.lsp: application/x-lisp
-.lsp: text/x-script.lisp
-.lst: text/plain
-.lsx: text/x-la-asf
-.lsx: video/x-la-asf
-.ltx: application/x-latex
-.lzh: application/octet-stream
-.lzh: application/x-lzh
-.lzx: application/lzx
-.lzx: application/octet-stream
-.lzx: application/x-lzx
-.m13: application/x-msmediaview
-.m14: application/x-msmediaview
-.m1v: video/mpeg
-.m2a: audio/mpeg
-.m2v: video/mpeg
-.m3u: audio/x-mpegurl
-.m: text/x-m
-.man: application/x-troff-man
-.map: application/x-navimap
-.mar: text/plain
-.mbd: application/mbedlet
-.mc: application/x-magic-cap-package-1.0
-.mcd: application/mcad
-.mcd: application/x-mathcad
-.mcf: image/vasa
-.mcf: text/mcf
-.mcp: application/netmc
-.mdb: application/x-msaccess
-.me: application/x-troff-me
-.mht: message/rfc822
-.mhtml: message/rfc822
-.mid: audio/mid
-.mid: audio/midi
-.mid: audio/x-mid
-.mid: audio/x-midi
-.midi: audio/midi
-.midi: audio/x-mid
-.midi: audio/x-midi
-.mif: application/x-frame
-.mif: application/x-mif
-.mime: message/rfc822
-.mime: www/mime
-.mjf: audio/x-vnd.audioexplosion.mjuicemediafile
-.mjpg: video/x-motion-jpeg
-.mm: application/base64
-.mm: application/x-meme
-.mme: application/base64
-.mml: text/mathml
-.mng: video/x-mng
-.mod: audio/mod
-.moov: video/quicktime
-.mov: video/quicktime
-.movie: video/x-sgi-movie
-.mp2: audio/mpeg
-.mp3: audio/mpeg
-.mpa: audio/mpeg
-.mpc: application/x-project
-.mpe: video/mpeg
-.mpeg: video/mpeg
-.mpg: video/mpeg
-.mpga: audio/mpeg
-.mpp: application/vnd.ms-project
-.mpt: application/x-project
-.mpv2: video/mpeg
-.mpv: application/x-project
-.mpx: application/x-project
-.mrc: application/marc
-.ms: application/x-troff-ms
-.msi: application/octet-stream
-.msm: application/octet-stream
-.msp: application/octet-stream
-.mv: video/x-sgi-movie
-.mvb: application/x-msmediaview
-.my: audio/make
-.mzz: application/x-vnd.audioexplosion.mzz
-.nap: image/naplps
-.naplps: image/naplps
-.nc: application/x-netcdf
-.ncm: application/vnd.nokia.configuration-message
-.nif: image/x-niff
-.niff: image/x-niff
-.nix: application/x-mix-transfer
-.nsc: application/x-conference
-.nvd: application/x-navidoc
-.nws: message/rfc822
-.o: application/octet-stream
-.oda: application/oda
-.omc: application/x-omc
-.omcd: application/x-omcdatamaker
-.omcr: application/x-omcregerator
-.p10: application/pkcs10
-.p10: application/x-pkcs10
-.p12: application/pkcs-12
-.p12: application/x-pkcs12
-.p7a: application/x-pkcs7-signature
-.p7b: application/x-pkcs7-certificates
-.p7c: application/pkcs7-mime
-.p7c: application/x-pkcs7-mime
-.p7m: application/pkcs7-mime
-.p7m: application/x-pkcs7-mime
-.p7r: application/x-pkcs7-certreqresp
-.p7s: application/pkcs7-signature
-.p7s: application/x-pkcs7-signature
-.p: text/x-pascal
-.part: application/pro_eng
-.pas: text/pascal
-.pbm: image/x-portable-bitmap
-.pcl: application/vnd.hp-pcl
-.pcl: application/x-pcl
-.pct: image/x-pict
-.pcx: image/x-pcx
-.pdb: application/x-pilot
-.pdf: application/pdf
-.pem: application/x-x509-ca-cert
-.pfunk: audio/make
-.pfunk: audio/make.my.funk
-.pfx: application/x-pkcs12
-.pgm: image/x-portable-graymap
-.pgm: image/x-portable-greymap
-.pic: image/pict
-.pict: image/pict
-.pkg: application/x-newton-compatible-pkg
-.pko: application/vnd.ms-pki.pko
-.pko: application/ynd.ms-pkipko
-.pl: application/x-perl
-.pl: text/plain
-.pl: text/x-script.perl
-.plx: application/x-pixclscript
-.pm4: application/x-pagemaker
-.pm5: application/x-pagemaker
-.pm: application/x-perl
-.pm: image/x-xpixmap
-.pm: text/x-script.perl-module
-.pma: application/x-perfmon
-.pmc: application/x-perfmon
-.pml: application/x-perfmon
-.pmr: application/x-perfmon
-.pmw: application/x-perfmon
-.png: image/png
-.pnm: application/x-portable-anymap
-.pnm: image/x-portable-anymap
-.pot,: application/vnd.ms-powerpoint
-.pot: application/mspowerpoint
-.pot: application/vnd.ms-powerpoint
-.pov: model/x-pov
-.ppa: application/vnd.ms-powerpoint
-.ppm: image/x-portable-pixmap
-.pps: application/mspowerpoint
-.ppt: application/mspowerpoint
-.ppz: application/mspowerpoint
-.prc: application/x-pilot
-.pre: application/x-freelance
-.prf: application/pics-rules
-.prt: application/pro_eng
-.ps: application/postscript
-.psd: application/octet-stream
-.pub: application/x-mspublisher
-.pvu: paleovu/x-pv
-.pwz: application/vnd.ms-powerpoint
-.py: text/x-script.phyton
-.pyc: applicaiton/x-bytecode.python
-.qcp: audio/vnd.qcelp
-.qd3: x-world/x-3dmf
-.qd3d: x-world/x-3dmf
-.qif: image/x-quicktime
-.qt: video/quicktime
-.qtc: video/x-qtc
-.qti: image/x-quicktime
-.qtif: image/x-quicktime
-.ra: audio/x-pn-realaudio
-.ra: audio/x-pn-realaudio-plugin
-.ra: audio/x-realaudio
-.ram: audio/x-pn-realaudio
-.rar: application/x-rar-compressed
-.ras: application/x-cmu-raster
-.ras: image/cmu-raster
-.ras: image/x-cmu-raster
-.rast: image/cmu-raster
-.rexx: text/x-script.rexx
-.rf: image/vnd.rn-realflash
-.rgb: image/x-rgb
-.rm: application/vnd.rn-realmedia
-.rm: audio/x-pn-realaudio
-.rmi: audio/mid
-.rmm: audio/x-pn-realaudio
-.rmp: audio/x-pn-realaudio
-.rmp: audio/x-pn-realaudio-plugin
-.rng: application/ringing-tones
-.rng: application/vnd.nokia.ringing-tone
-.rnx: application/vnd.rn-realplayer
-.roff: application/x-troff
-.rp: image/vnd.rn-realpix
-.rpm: application/x-redhat-package-manager
-.rpm: audio/x-pn-realaudio-plugin
-.rss: text/xml
-.rt: text/richtext
-.rt: text/vnd.rn-realtext
-.rtf: application/rtf
-.rtf: application/x-rtf
-.rtf: text/richtext
-.rtx: application/rtf
-.rtx: text/richtext
-.run: application/x-makeself
-.rv: video/vnd.rn-realvideo
-.s3m: audio/s3m
-.s: text/x-asm
-.saveme: application/octet-stream
-.sbk: application/x-tbook
-.scd: application/x-msschedule
-.scm: application/x-lotusscreencam
-.scm: text/x-script.guile
-.scm: text/x-script.scheme
-.scm: video/x-scm
-.sct: text/scriptlet
-.sdml: text/plain
-.sdp: application/sdp
-.sdp: application/x-sdp
-.sdr: application/sounder
-.sea: application/sea
-.sea: application/x-sea
-.set: application/set
-.setpay: application/set-payment-initiation
-.setreg: application/set-registration-initiation
-.sgm: text/sgml
-.sgm: text/x-sgml
-.sgml: text/sgml
-.sgml: text/x-sgml
-.sh: application/x-bsh
-.sh: application/x-sh
-.sh: application/x-shar
-.sh: text/x-script.sh
-.shar: application/x-bsh
-.shar: application/x-shar
-.shtml: text/html
-.shtml: text/x-server-parsed-html
-.sid: audio/x-psid
-.sit: application/x-sit
-.sit: application/x-stuffit
-.skd: application/x-koan
-.skm: application/x-koan
-.skp: application/x-koan
-.skt: application/x-koan
-.sl: application/x-seelogo
-.smi: application/smil
-.smil: application/smil
-.snd: audio/basic
-.snd: audio/x-adpcm
-.sol: application/solids
-.spc: application/x-pkcs7-certificates
-.spc: text/x-speech
-.spl: application/futuresplash
-.spr: application/x-sprite
-.sprite: application/x-sprite
-.src: application/x-wais-source
-.ssi: text/x-server-parsed-html
-.ssm: application/streamingmedia
-.sst: application/vnd.ms-pki.certstore
-.sst: application/vnd.ms-pkicertstore
-.step: application/step
-.stl: application/sla
-.stl: application/vnd.ms-pki.stl
-.stl: application/vnd.ms-pkistl
-.stl: application/x-navistyle
-.stm: text/html
-.stp: application/step
-.sv4cpio: application/x-sv4cpio
-.sv4crc: application/x-sv4crc
-.svf: image/vnd.dwg
-.svf: image/x-dwg
-.svg: image/svg+xml
-.svr: application/x-world
-.svr: x-world/x-svr
-.swf: application/x-shockwave-flash
-.t: application/x-troff
-.talk: text/x-speech
-.tar: application/x-tar
-.tbk: application/toolbook
-.tbk: application/x-tbook
-.tcl: application/x-tcl
-.tcl: text/x-script.tcl
-.tcsh: text/x-script.tcsh
-.tex: application/x-tex
-.texi: application/x-texinfo
-.texinfo: application/x-texinfo
-.text: application/plain
-.text: text/plain
-.tgz: application/gnutar
-.tgz: application/x-compressed
-.tif: image/tiff
-.tiff: image/tiff
-.tk: application/x-tcl
-.tr: application/x-troff
-.trm: application/x-msterminal
-.tsi: audio/tsp-audio
-.tsp: application/dsptype
-.tsp: audio/tsplayer
-.tsv: text/tab-separated-values
-.turbot: image/florian
-.txt: text/plain
-.uil: text/x-uil
-.uls: text/iuls
-.uni: text/uri-list
-.unis: text/uri-list
-.unv: application/i-deas
-.uri: text/uri-list
-.uris: text/uri-list
-.ustar: application/x-ustar
-.ustar: multipart/x-ustar
-.uu: application/octet-stream
-.uu: text/x-uuencode
-.uue: text/x-uuencode
-.vcd: application/x-cdlink
-.vcf: text/x-vcard
-.vcs: text/x-vcalendar
-.vda: application/vda
-.vdo: video/vdo
-.vew: application/groupwise
-.viv: video/vivo
-.viv: video/vnd.vivo
-.vivo: video/vivo
-.vivo: video/vnd.vivo
-.vmd: application/vocaltec-media-desc
-.vmf: application/vocaltec-media-file
-.voc: audio/voc
-.voc: audio/x-voc
-.vos: video/vosaic
-.vox: audio/voxware
-.vqe: audio/x-twinvq-plugin
-.vqf: audio/x-twinvq
-.vql: audio/x-twinvq-plugin
-.vrml: application/x-vrml
-.vrml: model/vrml
-.vrml: x-world/x-vrml
-.vrt: x-world/x-vrt
-.vsd: application/x-visio
-.vst: application/x-visio
-.vsw: application/x-visio
-.w60: application/wordperfect6.0
-.w61: application/wordperfect6.1
-.w6w: application/msword
-.war: application/java-archive
-.wav: audio/wav
-.wav: audio/x-wav
-.wb1: application/x-qpro
-.wbmp: image/vnd.wap.wbmp
-.wbmp: image/vnd.wap.wbmp
-.wcm: application/vnd.ms-works
-.wdb: application/vnd.ms-works
-.web: application/vnd.xara
-.wiz: application/msword
-.wk1: application/x-123
-.wks: application/vnd.ms-works
-.wmf: application/x-msmetafile
-.wmf: windows/metafile
-.wml: text/vnd.wap.wml
-.wmlc: application/vnd.wap.wmlc
-.wmls: text/vnd.wap.wmlscript
-.wmlsc: application/vnd.wap.wmlscriptc
-.wmv: video/x-ms-wmv
-.word: application/msword
-.wp5: application/wordperfect
-.wp6: application/wordperfect
-.wp: application/wordperfect
-.wpd: application/wordperfect
-.wps: application/vnd.ms-works
-.wq1: application/x-lotus
-.wri: application/mswrite
-.wrl: application/x-world
-.wsc: text/scriplet
-.wsrc: application/x-wais-source
-.wtk: application/x-wintalk
-.x-png: image/png
-.xaf: x-world/x-vrml
-.xbm: image/xbm
-.xdr: video/x-amt-demorun
-.xgz: xgl/drawing
-.xhtml: application/xhtml+xml
-.xif: image/vnd.xiff
-.xl: application/excel
-.xla: application/excel
-.xlb: application/excel
-.xlc: application/excel
-.xld: application/excel
-.xlk: application/excel
-.xll: application/excel
-.xlm: application/excel
-.xls: application/excel
-.xlt: application/excel
-.xlv: application/excel
-.xlw: application/excel
-.xm: audio/xm
-.xml: text/xml
-.xmz: xgl/movie
-.xof: x-world/x-vrml
-.xpi: application/x-xpinstall
-.xpix: application/x-vnd.ls-xpix
-.xpm: image/x-xpixmap
-.xpm: image/xpm
-.xsl: application/xslt+xml
-.xsr: video/x-amt-showrun
-.xwd: image/x-xwd
-.xwd: image/x-xwindowdump
-.xyz: chemical/x-pdb
-.z: application/x-compressed
-.zip: application/zip
-.zoo: application/octet-stream
-.zsh: text/x-script.zsh
diff --git a/lib/mongrel/header_out.rb b/lib/unicorn/header_out.rb
index 008bff8..a4d987c 100644
--- a/lib/mongrel/header_out.rb
+++ b/lib/unicorn/header_out.rb
@@ -1,4 +1,4 @@
-module Mongrel
+module Unicorn
   # This class implements a simple way of constructing the HTTP headers dynamically
   # via a Hash syntax.  Think of it as a write-only Hash.  Refer to HttpResponse for
   # information on how this is used.
diff --git a/lib/mongrel/semaphore.rb b/lib/unicorn/semaphore.rb
index 1c0b87c..1c0b87c 100644
--- a/lib/mongrel/semaphore.rb
+++ b/lib/unicorn/semaphore.rb
diff --git a/lib/mongrel/tcphack.rb b/lib/unicorn/tcphack.rb
index 634f9dd..634f9dd 100644
--- a/lib/mongrel/tcphack.rb
+++ b/lib/unicorn/tcphack.rb
diff --git a/lib/mongrel.rb b/lib/unicorn.rb
index dceb138..e43b676 100644
--- a/lib/mongrel.rb
+++ b/lib/unicorn.rb
@@ -10,25 +10,24 @@ require 'stringio'
 require 'fcntl'
 require 'logger'
 
-# Compiled Mongrel extension
+# Compiled extension
 require 'http11'
 
 # Gem conditional loader
 require 'thread'
 require 'rack'
 
-# Ruby Mongrel
-require 'mongrel/tcphack'
-require 'mongrel/const'
-require 'mongrel/http_request'
-require 'mongrel/header_out'
-require 'mongrel/http_response'
-require 'mongrel/semaphore'
+require 'unicorn/tcphack'
+require 'unicorn/const'
+require 'unicorn/http_request'
+require 'unicorn/header_out'
+require 'unicorn/http_response'
+require 'unicorn/semaphore'
 
# Mongrel module containing all of the classes (include C extensions) for running
# a Mongrel web server.  It contains a minimalist HTTP server with just enough
 # functionality to service web application requests fast as possible.
-module Mongrel
+module Unicorn
   class << self
     # A logger instance that conforms to the API of stdlib's Logger.
     attr_accessor :logger
@@ -48,7 +47,7 @@ module Mongrel
   class AcceptorError < StandardError; end
 
   #
# This is the main driver of Mongrel, while the Mongrel::HttpParser and Mongrel::URIClassifier
   # make up the majority of how the server functions.  It's a very simple class that just
   # has a thread accepting connections and a simple HttpServer.process_client function
   # to do the heavy lifting with the IO and Ruby.  
@@ -176,7 +175,7 @@ module Mongrel
     def reap_dead_workers(reason='unknown')
       if @workers.list.length > 0
         logger.info "Reaping #{@workers.list.length} threads for slow workers because of '#{reason}'"
-        error_msg = "Mongrel timed out this thread: #{reason}"
+        error_msg = "Unicorn timed out this thread: #{reason}"
         mark = Time.now
         @workers.list.each do |worker|
           worker[:started_on] = Time.now if not worker[:started_on]
@@ -10,25 +10,24 @@ require 'stringio'
 
-# Mongrel module containing all of the classes (include C extensions) for running
-# a Mongrel web server.  It contains a minimalist HTTP server with just enough
+# Unicorn module containing all of the classes (include C extensions) for running
+# a Unicorn web server.  It contains a minimalist HTTP server with just enough
 # functionality to service web application requests fast as possible.
@@ -48,7 +47,7 @@ module Mongrel
 
   #
-  # This is the main driver of Mongrel, while the Mongrel::HttpParser and Mongrel::URIClassifier
+  # This is the main driver of Unicorn, while the Unicorn::HttpParser and Unicorn::URIClassifier
   # make up the majority of how the server functions.  It's a very simple class that just
   # has a thread accepting connections and a simple HttpServer.process_client function
diff --git a/lib/mongrel/const.rb b/lib/unicorn/const.rb
index 994a2bf..56c3bb4 100644
--- a/lib/mongrel/const.rb
+++ b/lib/unicorn/const.rb
@@ -1,9 +1,9 @@
 
-module Mongrel
+module Unicorn
 
   # Every standard HTTP code mapped to the appropriate message.  These are
# used so frequently that they are placed directly in Mongrel for easy
# access rather than Mongrel::Const itself.
   HTTP_STATUS_CODES = {  
     100  => 'Continue',
     101  => 'Switching Protocols',
@@ -49,7 +49,7 @@ module Mongrel
   # gave about a 3% to 10% performance improvement over using the strings directly.
   # Symbols did not really improve things much compared to constants.
   #
# While Mongrel does try to emulate the CGI/1.2 protocol, it does not use the REMOTE_IDENT,
   # REMOTE_USER, or REMOTE_HOST parameters since those are either a security problem or
   # too taxing on performance.
   module Const
@@ -68,12 +68,12 @@ module Mongrel
     REQUEST_URI='REQUEST_URI'.freeze
     REQUEST_PATH='REQUEST_PATH'.freeze
     
-    MONGREL_VERSION="2.0".freeze
+    UNICORN_VERSION="0.2.0".freeze
 
-    MONGREL_TMP_BASE="mongrel".freeze
+    UNICORN_TMP_BASE="unicorn".freeze
 
     # The standard empty 404 response for bad requests.  Use Error4040Handler for custom stuff.
-    ERROR_404_RESPONSE="HTTP/1.1 404 Not Found\r\nConnection: close\r\nServer: Mongrel #{MONGREL_VERSION}\r\n\r\nNOT FOUND".freeze
+    ERROR_404_RESPONSE="HTTP/1.1 404 Not Found\r\nConnection: close\r\nServer: Unicorn #{UNICORN_VERSION}\r\n\r\nNOT FOUND".freeze
 
     CONTENT_LENGTH="CONTENT_LENGTH".freeze
 
@@ -110,4 +110,4 @@ module Mongrel
     REDIRECT = "HTTP/1.1 302 Found\r\nLocation: %s\r\nConnection: close\r\n\r\n".freeze
     HOST = "HOST".freeze
   end
-end \ No newline at end of file
+end
@@ -1,9 +1,9 @@
 
   # Every standard HTTP code mapped to the appropriate message.  These are
-  # used so frequently that they are placed directly in Mongrel for easy
-  # access rather than Mongrel::Const itself.
+  # used so frequently that they are placed directly in Unicorn for easy
+  # access rather than Unicorn::Const itself.
   HTTP_STATUS_CODES = {  
     100  => 'Continue',
@@ -49,7 +49,7 @@ module Mongrel
   # Symbols did not really improve things much compared to constants.
   #
-  # While Mongrel does try to emulate the CGI/1.2 protocol, it does not use the REMOTE_IDENT,
+  # While Unicorn does try to emulate the CGI/1.2 protocol, it does not use the REMOTE_IDENT,
   # REMOTE_USER, or REMOTE_HOST parameters since those are either a security problem or
   # too taxing on performance.
diff --git a/lib/mongrel/http_request.rb b/lib/unicorn/http_request.rb
index 86c0e15..a76d4e0 100644
--- a/lib/mongrel/http_request.rb
+++ b/lib/unicorn/http_request.rb
@@ -1,5 +1,5 @@
 
-module Mongrel
+module Unicorn
   #
   # The HttpRequest.initialize method will convert any request that is larger than
   # Const::MAX_BODY into a Tempfile and use that as the body.  Otherwise it uses
@@ -28,7 +28,7 @@ module Mongrel
         # must read more data to complete body
         if remain > Const::MAX_BODY
           # huge body, put it in a tempfile
-          @body = Tempfile.new(Const::MONGREL_TMP_BASE)
+          @body = Tempfile.new(Const::UNICORN_TMP_BASE)
           @body.binmode
         else
           # small body, just use that
@@ -43,7 +43,7 @@ module Mongrel
     end
 
     # Returns an environment which is rackable: http://rack.rubyforge.org/doc/files/SPEC.html
# Copied directly from Rack's old Mongrel handler.
     def env
       env = params.clone
       env["QUERY_STRING"] ||= ''
@@ -43,7 +43,7 @@ module Mongrel
 
     # Returns an environment which is rackable: http://rack.rubyforge.org/doc/files/SPEC.html
-    # Copied directly from Rack's old Mongrel handler.
+    # Copied directly from Rack's old Unicorn handler.
     def env
       env = params.clone
diff --git a/lib/mongrel/http_response.rb b/lib/unicorn/http_response.rb
index 17b6d6b..5fbc990 100644
--- a/lib/mongrel/http_response.rb
+++ b/lib/unicorn/http_response.rb
@@ -1,4 +1,4 @@
-module Mongrel
+module Unicorn
   # Writes and controls your response to the client using the HTTP/1.1 specification.
   # You use it by simply doing:
   #
@@ -7,7 +7,7 @@ module Mongrel
   #    out.write("hello\n")
   #  end
   #
# The parameter to start is the response code--which Mongrel will translate for you
   # based on HTTP_STATUS_CODES.  The head parameter is how you write custom headers.
   # The out parameter is where you write your body.  The default status code for
   # HttpResponse.start is 200 so the above example is redundant.
@@ -7,7 +7,7 @@ module Mongrel
   #  end
   #
-  # The parameter to start is the response code--which Mongrel will translate for you
+  # The parameter to start is the response code--which Unicorn will translate for you
   # based on HTTP_STATUS_CODES.  The head parameter is how you write custom headers.
   # The out parameter is where you write your body.  The default status code for